@@ -1,10 +1,12 @@
+use crate::SteamID;
+use serde::Deserialize;
 use std::fmt;
 
 pub const AUTHORITY: &str = "api.steampowered.com";
 
 #[derive(Debug)]
 pub struct Error {
-    cause: String,
+    pub cause: String,
 }
 
 impl fmt::Display for Error {
@@ -54,3 +56,19 @@ impl From<std::num::ParseIntError> for Error {
 }
 
 pub type Result<T> = std::result::Result<T, Error>;
+
+#[derive(Deserialize)]
+pub(crate) struct ResponseWrapper<R> {
+    pub(crate) response: R,
+}
+
+#[derive(Deserialize)]
+pub(crate) struct PlayersWrapper<P> {
+    pub(crate) players: Vec<P>,
+}
+
+pub(crate) fn concat_steam_ids(ids: Vec<SteamID>) -> String {
+    ids.iter()
+        .map(|id| id.to_string())
+        .fold("".to_owned(), |a, b| a + &b + ",")
+}
